@@ -1,7 +1,7 @@
 # legacy imports, future imports should use the full import path
 from blazeutils.datastructures import DumbObject, OrderedProperties, OrderedDict, \
     HtmlAttributeHolder
-from blazeutils.datetime import safe_strftime
+from blazeutils.dates import safe_strftime
 from blazeutils.decorators import decorator, curry
 from blazeutils.error_handling import tb_depth_in, traceback_depth
 from blazeutils.filesystem import randfile
@@ -17,4 +17,4 @@ from blazeutils.strings import StringIndenter, simplify_string, case_cw2us, \
     case_mc2us, case_us2cw, case_us2mc, randchars, \
     randhash, randnumerics, reindent, simplify_string
 
-VERSION = '0.3.3'
+VERSION = '0.3.4'
